# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .user_role_with_resource_resource_type import UserRoleWithResourceResourceType


class UserRoleWithResource(UniversalBaseModel):
    role_id: typing_extensions.Annotated[str, FieldMetadata(alias="roleId")]
    resource_type: typing_extensions.Annotated[UserRoleWithResourceResourceType, FieldMetadata(alias="resourceType")]
    resource_id: typing_extensions.Annotated[str, FieldMetadata(alias="resourceId")]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
