# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .artifact_type import ArtifactType
from .base_artifact_version import BaseArtifactVersion
from .subject import Subject


class Artifact(UniversalBaseModel):
    id: str
    ml_repo_id: str
    type: ArtifactType
    name: str
    fqn: str
    created_by_subject: Subject
    created_at: typing.Optional[dt.datetime] = None
    updated_at: typing.Optional[dt.datetime] = None
    latest_version: typing.Optional[BaseArtifactVersion] = None
    run_steps: typing.Optional[typing.List[int]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
