# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .rate_limit_rule import RateLimitRule


class RateLimitConfig(UniversalBaseModel):
    """
    Rate Limit Configuration
    """

    name: str = pydantic.Field()
    """
    Name of the rate limiting configuration
    """

    type: typing.Literal["gateway-rate-limiting-config"] = pydantic.Field(default="gateway-rate-limiting-config")
    """
    +value=gateway-rate-limiting-config
    +sort=2
    """

    rules: typing.List[RateLimitRule] = pydantic.Field()
    """
    List of rate limit rules
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
