# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ....core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ....core.serialization import FieldMetadata


class DockerRegistriesGetCredentialsResponse(UniversalBaseModel):
    fqn: typing.Optional[str] = pydantic.Field(default=None)
    """
    Docker registry FQN
    """

    registry_url: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="registryUrl")] = (
        pydantic.Field(default=None)
    )
    """
    Docker registry URL
    """

    username: typing.Optional[str] = pydantic.Field(default=None)
    """
    Username
    """

    password: typing.Optional[str] = pydantic.Field(default=None)
    """
    Password
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
