# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .span_field_filter_operator import SpanFieldFilterOperator
from .span_field_filter_span_field_name import SpanFieldFilterSpanFieldName
from .span_field_filter_value import SpanFieldFilterValue


class SpanFieldFilter(UniversalBaseModel):
    span_field_name: typing_extensions.Annotated[SpanFieldFilterSpanFieldName, FieldMetadata(alias="spanFieldName")]
    operator: SpanFieldFilterOperator
    value: SpanFieldFilterValue

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
