# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class AwsAccessKeyAuth(UniversalBaseModel):
    aws_access_key_id: str = pydantic.Field()
    """
    AWS Access Key ID
    """

    aws_secret_access_key: str = pydantic.Field()
    """
    AWS Secret Access Key for the user to authenticate with
    """

    aws_session_token: typing.Optional[str] = pydantic.Field(default=None)
    """
    AWS Session Token, only required when using temporary credentials
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
