# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.sso_team_manifest import SsoTeamManifest
from ...types.team_manifest import TeamManifest

ApplyTeamRequestManifest = typing.Union[TeamManifest, SsoTeamManifest]
