# This file was auto-generated by Fern from our API Definition.

import typing

from .aws_sqs_access_key_based_auth import AwsSqsAccessKeyBasedAuth
from .aws_sqs_assumed_role_based_auth import AwsSqsAssumedRoleBasedAuth

SqsQueueMetricConfigAuth = typing.Union[AwsSqsAccessKeyBasedAuth, AwsSqsAssumedRoleBasedAuth]
