# This file was auto-generated by Fern from our API Definition.

import typing

from .otel_exporter_grpc_config import OtelExporterGrpcConfig
from .otel_exporter_http_config import OtelExporterHttpConfig

GatewayOtelConfigOtelTracesExporterConfig = typing.Union[OtelExporterHttpConfig, OtelExporterGrpcConfig]
