# This file was auto-generated by Fern from our API Definition.

import typing

from .assistant_message_content_one_item import AssistantMessageContentOneItem
from .blob_storage_reference import BlobStorageReference

AssistantMessageContent = typing.Union[str, typing.List[AssistantMessageContentOneItem], BlobStorageReference]
