# This file was auto-generated by Fern from our API Definition.

import typing

from .aws_access_key_based_auth import AwsAccessKeyBasedAuth
from .aws_assumed_role_based_auth import AwsAssumedRoleBasedAuth

AwsParameterStoreAuthData = typing.Union[AwsAccessKeyBasedAuth, AwsAssumedRoleBasedAuth]
