# This file was auto-generated by Fern from our API Definition.

import typing

from ..core import enum

T_Result = typing.TypeVar("T_Result")


class MultiPartUploadStorageProvider(enum.StrEnum):
    """
    An enumeration.
    """

    S3COMPATIBLE = "S3_COMPATIBLE"
    AZURE_BLOB = "AZURE_BLOB"

    def visit(self, s3compatible: typing.Callable[[], T_Result], azure_blob: typing.Callable[[], T_Result]) -> T_Result:
        if self is MultiPartUploadStorageProvider.S3COMPATIBLE:
            return s3compatible()
        if self is MultiPartUploadStorageProvider.AZURE_BLOB:
            return azure_blob()
