# This file was auto-generated by Fern from our API Definition.

import typing

from .aws_provider_account import AwsProviderAccount
from .azure_provider_account import AzureProviderAccount
from .bitbucket_provider_account import BitbucketProviderAccount
from .custom_provider_account import CustomProviderAccount
from .dockerhub_provider_account import DockerhubProviderAccount
from .gcp_provider_account import GcpProviderAccount
from .github_provider_account import GithubProviderAccount
from .gitlab_provider_account import GitlabProviderAccount
from .hashicorp_provider_account import HashicorpProviderAccount
from .jfrog_provider_account import JfrogProviderAccount
from .pager_duty_provider_account import PagerDutyProviderAccount
from .quay_provider_account import QuayProviderAccount
from .slack_provider_account import SlackProviderAccount
from .true_foundry_provider_account import TrueFoundryProviderAccount
from .ttl_provider_account import TtlProviderAccount
from .webhook_provider_account import WebhookProviderAccount

InfraProviderAccount = typing.Union[
    AwsProviderAccount,
    AzureProviderAccount,
    GcpProviderAccount,
    DockerhubProviderAccount,
    BitbucketProviderAccount,
    CustomProviderAccount,
    GithubProviderAccount,
    GitlabProviderAccount,
    JfrogProviderAccount,
    TtlProviderAccount,
    TrueFoundryProviderAccount,
    QuayProviderAccount,
    SlackProviderAccount,
    WebhookProviderAccount,
    PagerDutyProviderAccount,
    HashicorpProviderAccount,
]
