# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .parameters_stop import ParametersStop


class Parameters(UniversalBaseModel):
    """
    Parameters to pass to the model when generating
    """

    max_tokens: typing.Optional[int] = None
    temperature: typing.Optional[float] = None
    top_k: typing.Optional[float] = None
    top_p: typing.Optional[float] = None
    stop: typing.Optional[ParametersStop] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
