# This file was auto-generated by Fern from our API Definition.

import typing

from ..core import enum

T_Result = typing.TypeVar("T_Result")


class OtelExporterHttpConfigEncoding(enum.StrEnum):
    """
    Encoding for OpenTelemetry data
    """

    PROTO = "proto"
    JSON = "json"

    def visit(self, proto: typing.Callable[[], T_Result], json: typing.Callable[[], T_Result]) -> T_Result:
        if self is OtelExporterHttpConfigEncoding.PROTO:
            return proto()
        if self is OtelExporterHttpConfigEncoding.JSON:
            return json()
