# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class LocalSource(UniversalBaseModel):
    """
    Describes that we are using code stored in a local developement environment to build our image
    """

    type: typing.Literal["local"] = pydantic.Field(default="local")
    """
    +value=local
    """

    project_root_path: str = pydantic.Field(default="./")
    """
    Local project root path.
    """

    local_build: bool = pydantic.Field(default=True)
    """
    run docker build locally
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
