# This file was auto-generated by Fern from our API Definition.

import typing

from .custom_basic_auth import CustomBasicAuth
from .custom_bearer_auth import CustomBearerAuth

SelfHostedModelAuthData = typing.Union[CustomBasicAuth, CustomBearerAuth]
