# This file was auto-generated by Fern from our API Definition.

import typing

from .fast_ai_framework import FastAiFramework
from .gluon_framework import GluonFramework
from .h2o_framework import H2OFramework
from .keras_framework import KerasFramework
from .light_gbm_framework import LightGbmFramework
from .onnx_framework import OnnxFramework
from .paddle_framework import PaddleFramework
from .py_torch_framework import PyTorchFramework
from .sklearn_framework import SklearnFramework
from .spa_cy_framework import SpaCyFramework
from .stats_models_framework import StatsModelsFramework
from .tensor_flow_framework import TensorFlowFramework
from .transformers_framework import TransformersFramework
from .xg_boost_framework import XgBoostFramework

ModelManifestFramework = typing.Union[
    TransformersFramework,
    TensorFlowFramework,
    SklearnFramework,
    PyTorchFramework,
    KerasFramework,
    XgBoostFramework,
    LightGbmFramework,
    FastAiFramework,
    H2OFramework,
    OnnxFramework,
    SpaCyFramework,
    StatsModelsFramework,
    GluonFramework,
    PaddleFramework,
]
