# This file was auto-generated by Fern from our API Definition.

import typing

from .node_selector import NodeSelector
from .nodepool_selector import NodepoolSelector

ResourcesNode = typing.Union[NodeSelector, NodepoolSelector]
