# This file was auto-generated by Fern from our API Definition.

import typing

from ..core import enum

T_Result = typing.TypeVar("T_Result")


class ArtifactType(enum.StrEnum):
    """
    An enumeration.
    """

    ARTIFACT = "artifact"
    MODEL = "model"
    PLOT = "plot"
    IMAGE = "image"
    CHAT_PROMPT = "chat_prompt"

    def visit(
        self,
        artifact: typing.Callable[[], T_Result],
        model: typing.Callable[[], T_Result],
        plot: typing.Callable[[], T_Result],
        image: typing.Callable[[], T_Result],
        chat_prompt: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is ArtifactType.ARTIFACT:
            return artifact()
        if self is ArtifactType.MODEL:
            return model()
        if self is ArtifactType.PLOT:
            return plot()
        if self is ArtifactType.IMAGE:
            return image()
        if self is ArtifactType.CHAT_PROMPT:
            return chat_prompt()
