# This file was auto-generated by Fern from our API Definition.

import typing

from .local_source import LocalSource
from .remote_source import RemoteSource

WorkflowSource = typing.Union[LocalSource, RemoteSource]
