# This file was auto-generated by Fern from our API Definition.

import typing

from .blob_storage_reference import BlobStorageReference
from .user_message_content_one_item import UserMessageContentOneItem

UserMessageContent = typing.Union[str, typing.List[UserMessageContentOneItem], BlobStorageReference]
