# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .user_metadata import UserMetadata
from .user_role_with_resource import UserRoleWithResource


class User(UniversalBaseModel):
    id: str
    email: str
    tenant_name: typing_extensions.Annotated[str, FieldMetadata(alias="tenantName")]
    metadata: UserMetadata
    roles: typing.Optional[typing.List[str]] = None
    roles_with_resource: typing_extensions.Annotated[
        typing.Optional[typing.List[UserRoleWithResource]], FieldMetadata(alias="rolesWithResource")
    ] = None
    active: bool
    created_at: typing_extensions.Annotated[dt.datetime, FieldMetadata(alias="createdAt")]
    updated_at: typing_extensions.Annotated[dt.datetime, FieldMetadata(alias="updatedAt")]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
