# This file was auto-generated by Fern from our API Definition.

import typing

from .budget_config import BudgetConfig
from .gateway_otel_config import GatewayOtelConfig
from .guardrails_config import GuardrailsConfig
from .load_balancing_config import LoadBalancingConfig
from .rate_limit_config import RateLimitConfig

GatewayConfig = typing.Union[RateLimitConfig, LoadBalancingConfig, GuardrailsConfig, BudgetConfig, GatewayOtelConfig]
