# This file was auto-generated by Fern from our API Definition.

import typing

from .external_blob_storage_source import ExternalBlobStorageSource
from .local_model_source import LocalModelSource
from .true_foundry_managed_source import TrueFoundryManagedSource

ModelManifestSource = typing.Union[TrueFoundryManagedSource, ExternalBlobStorageSource, LocalModelSource]
