# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel, update_forward_refs
from .pagination import Pagination


class ListApplicationsResponse(UniversalBaseModel):
    data: typing.List["Application"] = pydantic.Field()
    """
    Array of Applications
    """

    pagination: Pagination = pydantic.Field()
    """
    Pagination information
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow


from .application import Application  # noqa: E402, I001
from .application_debug_info import ApplicationDebugInfo  # noqa: E402, I001
from .deployment import Deployment  # noqa: E402, I001

update_forward_refs(
    ListApplicationsResponse, Application=Application, ApplicationDebugInfo=ApplicationDebugInfo, Deployment=Deployment
)
