# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class ArtifactsCacheVolume(UniversalBaseModel):
    """
    Describes the volume that will be used to cache the models
    """

    storage_class: str = pydantic.Field()
    """
    Storage class of the Volume where artifacts will be cached
    """

    cache_size: int = pydantic.Field(default=200)
    """
    Size of the Volume (in GB) where artifacts will be cached. Should be greater than twice the size of artifacts getting cached
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
