# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .azure_basic_auth import AzureBasicAuth


class AzureContainerRegistry(UniversalBaseModel):
    """
    Azure ACR
    """

    type: typing.Literal["integration/docker-registry/azure/acr"] = pydantic.Field(
        default="integration/docker-registry/azure/acr"
    )
    """
    +value=integration/docker-registry/azure/acr
    """

    name: str = pydantic.Field()
    """
    The name of the integration that will be displayed in the TrueFoundry UI.
    """

    registry_url: str = pydantic.Field()
    """
    The URL of the registry.
    """

    auth_data: typing.Optional[AzureBasicAuth] = None
    authorized_subjects: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    List of subjects that are authorized to access this integration. List of user fqn in format <user_type>:<username>.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
