# This file was auto-generated by Fern from our API Definition.

import typing

from .guardrail_config_group import GuardrailConfigGroup
from .infra_provider_account import InfraProviderAccount
from .mcp_server_provider_account import McpServerProviderAccount
from .model_provider_account import ModelProviderAccount

ProviderAccounts = typing.Union[
    InfraProviderAccount, ModelProviderAccount, McpServerProviderAccount, GuardrailConfigGroup
]
