# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class Log(UniversalBaseModel):
    job_name: typing.Optional[str] = pydantic.Field(default=None)
    """
    Job Name
    """

    log: str = pydantic.Field()
    """
    Log Content
    """

    stream: str = pydantic.Field()
    """
    Log Stream
    """

    time: str = pydantic.Field()
    """
    Log Time
    """

    container_name: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="containerName")] = (
        pydantic.Field(default=None)
    )
    """
    Container Name
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
