# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.artifact_manifest import ArtifactManifest
from ...types.model_manifest import ModelManifest

StageArtifactRequestManifest = typing.Union[ModelManifest, ArtifactManifest]
