# This file was auto-generated by Fern from our API Definition.

import typing

from .application_set import ApplicationSet
from .async_service import AsyncService
from .codeserver import Codeserver
from .helm import Helm
from .intercept import Intercept
from .job import Job
from .notebook import Notebook
from .r_studio import RStudio
from .service import Service
from .spark_job import SparkJob
from .ssh_server import SshServer
from .volume import Volume
from .workflow import Workflow

DeploymentManifest = typing.Union[
    Service,
    AsyncService,
    Job,
    Notebook,
    Codeserver,
    SshServer,
    RStudio,
    Helm,
    Volume,
    ApplicationSet,
    Workflow,
    SparkJob,
    Intercept,
]
