# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .aws_parameter_store_auth_data import AwsParameterStoreAuthData
from .aws_region import AwsRegion


class AwsParameterStore(UniversalBaseModel):
    """
    AWS Parameter Store
    """

    type: typing.Literal["integration/secret-store/aws/parameter-store"] = pydantic.Field(
        default="integration/secret-store/aws/parameter-store"
    )
    """
    +value=integration/secret-store/aws/parameter-store
    """

    name: str = pydantic.Field()
    """
    The name of the integration that will be displayed in the TrueFoundry UI.
    """

    region: AwsRegion
    auth_data: typing.Optional[AwsParameterStoreAuthData] = pydantic.Field(default=None)
    """
    Custom authentication data for the integration.
    """

    authorized_subjects: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    List of subjects that are authorized to access this integration. List of user fqn in format <user_type>:<username>.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
