# This file was auto-generated by Fern from our API Definition.

import typing

from .git_helm_repo import GitHelmRepo
from .helm_repo import HelmRepo
from .oci_repo import OciRepo

HelmSource = typing.Union[HelmRepo, OciRepo, GitHelmRepo]
