# This file was auto-generated by Fern from our API Definition.

import typing

from ..core import enum

T_Result = typing.TypeVar("T_Result")


class AzurePiiGuardrailConfigDomain(enum.StrEnum):
    """
    Specialized domain for PII detection. Use healthcare for PHI (Protected Health Information) or none for general text
    """

    NONE = "none"
    HEALTHCARE = "healthcare"

    def visit(self, none: typing.Callable[[], T_Result], healthcare: typing.Callable[[], T_Result]) -> T_Result:
        if self is AzurePiiGuardrailConfigDomain.NONE:
            return none()
        if self is AzurePiiGuardrailConfigDomain.HEALTHCARE:
            return healthcare()
