# This file was auto-generated by Fern from our API Definition.

import typing

from .amqp_input_config import AmqpInputConfig
from .kafka_input_config import KafkaInputConfig
from .nats_input_config import NatsInputConfig
from .sqs_input_config import SqsInputConfig

WorkerConfigInputConfig = typing.Union[SqsInputConfig, NatsInputConfig, KafkaInputConfig, AmqpInputConfig]
