# This file was auto-generated by Fern from our API Definition.

import typing

from .slack_bot_integration import SlackBotIntegration
from .slack_webhook_integration import SlackWebhookIntegration

SlackIntegrations = typing.Union[SlackWebhookIntegration, SlackBotIntegration]
