# This file was auto-generated by Fern from our API Definition.

import typing

from ..core import enum

T_Result = typing.TypeVar("T_Result")


class EnvironmentOptimizeFor(enum.StrEnum):
    COST = "COST"
    AVAILABILITY = "AVAILABILITY"

    def visit(self, cost: typing.Callable[[], T_Result], availability: typing.Callable[[], T_Result]) -> T_Result:
        if self is EnvironmentOptimizeFor.COST:
            return cost()
        if self is EnvironmentOptimizeFor.AVAILABILITY:
            return availability()
