# This file was auto-generated by Fern from our API Definition.

import typing

from .blue_green import BlueGreen
from .canary import Canary
from .rolling import Rolling

ServiceRolloutStrategy = typing.Union[Rolling, Canary, BlueGreen]
