# This file was auto-generated by Fern from our API Definition.

import typing

from .blob_storage_reference import BlobStorageReference

TextContentPartText = typing.Union[str, BlobStorageReference]
