# This file was auto-generated by Fern from our API Definition.

import typing

from ...core import enum

T_Result = typing.TypeVar("T_Result")


class TeamsListRequestType(enum.StrEnum):
    TEAM = "team"
    SSO_TEAM = "sso-team"

    def visit(self, team: typing.Callable[[], T_Result], sso_team: typing.Callable[[], T_Result]) -> T_Result:
        if self is TeamsListRequestType.TEAM:
            return team()
        if self is TeamsListRequestType.SSO_TEAM:
            return sso_team()
