# This file was auto-generated by Fern from our API Definition.

import typing

from .ai_features_settings import AiFeaturesSettings
from .alert_config import AlertConfig
from .application_set import ApplicationSet
from .artifact_manifest import ArtifactManifest
from .async_service import AsyncService
from .chat_prompt_manifest import ChatPromptManifest
from .cluster_manifest import ClusterManifest
from .common_tools_settings import CommonToolsSettings
from .data_directory import DataDirectory
from .gateway_config import GatewayConfig
from .helm import Helm
from .job import Job
from .ml_repo_manifest import MlRepoManifest
from .model_manifest import ModelManifest
from .notebook import Notebook
from .policy_manifest import PolicyManifest
from .provider_accounts import ProviderAccounts
from .r_studio import RStudio
from .role_manifest import RoleManifest
from .secret_group_manifest import SecretGroupManifest
from .service import Service
from .spark_job import SparkJob
from .ssh_server import SshServer
from .team_manifest import TeamManifest
from .virtual_account_manifest import VirtualAccountManifest
from .volume import Volume
from .workflow import Workflow
from .workspace_manifest import WorkspaceManifest

TrueFoundryApplyRequestManifest = typing.Union[
    MlRepoManifest,
    ArtifactManifest,
    ModelManifest,
    ChatPromptManifest,
    DataDirectory,
    Service,
    ApplicationSet,
    ProviderAccounts,
    ClusterManifest,
    WorkspaceManifest,
    Job,
    Helm,
    Volume,
    Notebook,
    RStudio,
    Workflow,
    AsyncService,
    SshServer,
    SparkJob,
    GatewayConfig,
    TeamManifest,
    PolicyManifest,
    RoleManifest,
    AlertConfig,
    VirtualAccountManifest,
    CommonToolsSettings,
    AiFeaturesSettings,
    SecretGroupManifest,
]
