# This file was auto-generated by Fern from our API Definition.

import typing

from ..core import enum

T_Result = typing.TypeVar("T_Result")


class LogsSearchOperatorType(enum.StrEnum):
    """
    Comparison operator logs search
    """

    EQUAL = "equal"
    NOT_EQUAL = "not_equal"

    def visit(self, equal: typing.Callable[[], T_Result], not_equal: typing.Callable[[], T_Result]) -> T_Result:
        if self is LogsSearchOperatorType.EQUAL:
            return equal()
        if self is LogsSearchOperatorType.NOT_EQUAL:
            return not_equal()
