# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class NodepoolSelector(UniversalBaseModel):
    """
    Specify one or more nodepools to run your application on.
    """

    type: typing.Literal["nodepool_selector"] = pydantic.Field(default="nodepool_selector")
    """
    +value=nodepool_selector
    """

    nodepools: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Nodepools where you want to run your workload. Multiple nodepools can be selected.
     The workload is guaranteed to be scheduled on one of the nodepool
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
