# This file was auto-generated by Fern from our API Definition.

import typing

from .forward_action import ForwardAction
from .mirror_action import MirrorAction

InterceptRulesItemAction = typing.Union[ForwardAction, MirrorAction]
