# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class SlaCutoff(UniversalBaseModel):
    time_per_output_token_ms: typing.Optional[int] = pydantic.Field(default=None)
    """
    Time per output token threshold in milliseconds. If time per output token exceeds this value, the target will be marked as unhealthy
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
