# This file was auto-generated by Fern from our API Definition.

import typing

from .task_docker_file_build import TaskDockerFileBuild
from .task_python_build import TaskPythonBuild

PythonTaskConfigImage = typing.Union[TaskPythonBuild, TaskDockerFileBuild]
