# This file was auto-generated by Fern from our API Definition.

import typing

from ..core import enum

T_Result = typing.TypeVar("T_Result")


class IChangeOperation(enum.StrEnum):
    REMOVE = "REMOVE"
    ADD = "ADD"
    UPDATE = "UPDATE"

    def visit(
        self,
        remove: typing.Callable[[], T_Result],
        add: typing.Callable[[], T_Result],
        update: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is IChangeOperation.REMOVE:
            return remove()
        if self is IChangeOperation.ADD:
            return add()
        if self is IChangeOperation.UPDATE:
            return update()
