# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .intercept_rules_item import InterceptRulesItem


class Intercept(UniversalBaseModel):
    type: typing.Literal["intercept"] = pydantic.Field(default="intercept")
    """
    +value=intercept
    """

    name: str = pydantic.Field()
    """
    Name of the service this intercept is for
    """

    rules: typing.List[InterceptRulesItem]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
