# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class RetryConfig(UniversalBaseModel):
    attempts: int = pydantic.Field()
    """
    Number of attempts to retry the request
    """

    delay: typing.Optional[int] = pydantic.Field(default=100)
    """
    Delay between retries in milliseconds
    """

    on_status_codes: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Status codes to retry on
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
