# This file was auto-generated by Fern from our API Definition.

import typing

from .latency_based_load_balancing import LatencyBasedLoadBalancing
from .priority_based_load_balancing import PriorityBasedLoadBalancing
from .weight_based_load_balancing import WeightBasedLoadBalancing

ChatPromptManifestRoutingConfig = typing.Union[
    WeightBasedLoadBalancing, LatencyBasedLoadBalancing, PriorityBasedLoadBalancing
]
