# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel, update_forward_refs
from .addon_component import AddonComponent
from .pagination import Pagination


class ListClusterAddonsResponse(UniversalBaseModel):
    data: typing.List[AddonComponent] = pydantic.Field()
    """
    Array of Cluster Addons
    """

    pagination: Pagination = pydantic.Field()
    """
    Pagination information
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow


update_forward_refs(ListClusterAddonsResponse)
