# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .multi_part_upload_storage_provider import MultiPartUploadStorageProvider
from .signed_url import SignedUrl


class MultiPartUpload(UniversalBaseModel):
    storage_provider: MultiPartUploadStorageProvider
    part_signed_urls: typing.List[SignedUrl]
    s3compatible_upload_id: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="s3_compatible_upload_id")
    ] = None
    azure_blob_block_ids: typing.Optional[typing.List[str]] = None
    finalize_signed_url: SignedUrl

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
