# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .data_directory_manifest import DataDirectoryManifest
from .subject import Subject


class DataDirectory(UniversalBaseModel):
    id: str
    ml_repo_id: str
    name: str
    fqn: str
    created_by_subject: Subject
    created_at: dt.datetime
    updated_at: dt.datetime
    manifest: DataDirectoryManifest
    usage_code_snippet: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
