# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .true_foundry_apply_response_action import TrueFoundryApplyResponseAction
from .true_foundry_apply_response_existing_manifest import TrueFoundryApplyResponseExistingManifest


class TrueFoundryApplyResponse(UniversalBaseModel):
    existing_manifest: typing_extensions.Annotated[
        typing.Optional[TrueFoundryApplyResponseExistingManifest], FieldMetadata(alias="existingManifest")
    ] = pydantic.Field(default=None)
    """
    The existing manifest of the resource
    """

    action: typing.Optional[TrueFoundryApplyResponseAction] = pydantic.Field(default=None)
    """
    The action performed: CREATE or UPDATE
    """

    data: typing.Optional[typing.Dict[str, typing.Any]] = pydantic.Field(default=None)
    """
    The created or updated resource
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
