# This file was auto-generated by Fern from our API Definition.

import typing

from ..core import enum

T_Result = typing.TypeVar("T_Result")


class AzureContentSafetyCategory(enum.StrEnum):
    HATE = "Hate"
    SELF_HARM = "SelfHarm"
    SEXUAL = "Sexual"
    VIOLENCE = "Violence"

    def visit(
        self,
        hate: typing.Callable[[], T_Result],
        self_harm: typing.Callable[[], T_Result],
        sexual: typing.Callable[[], T_Result],
        violence: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is AzureContentSafetyCategory.HATE:
            return hate()
        if self is AzureContentSafetyCategory.SELF_HARM:
            return self_harm()
        if self is AzureContentSafetyCategory.SEXUAL:
            return sexual()
        if self is AzureContentSafetyCategory.VIOLENCE:
            return violence()
