# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .sync_token_in_secret_store_info import SyncTokenInSecretStoreInfo


class SyncVirtualAccountTokenResponse(UniversalBaseModel):
    sync_token_in_secret_store_info: typing_extensions.Annotated[
        SyncTokenInSecretStoreInfo, FieldMetadata(alias="syncTokenInSecretStoreInfo")
    ] = pydantic.Field()
    """
    Sync status including timestamp and error (if any)
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
