# This file was auto-generated by Fern from our API Definition.

import typing

from .image_content_part import ImageContentPart
from .text_content_part import TextContentPart

UserMessageContentOneItem = typing.Union[TextContentPart, ImageContentPart]
