# This file was auto-generated by Fern from our API Definition.

import typing

from .azure_aks_integration import AzureAksIntegration
from .azure_blob_storage import AzureBlobStorage
from .azure_container_registry import AzureContainerRegistry
from .azure_repos_integration import AzureReposIntegration
from .azure_vault import AzureVault

AzureIntegrations = typing.Union[
    AzureAksIntegration, AzureContainerRegistry, AzureBlobStorage, AzureVault, AzureReposIntegration
]
