# This file was auto-generated by Fern from our API Definition.

import typing

from .huggingface_artifact_source import HuggingfaceArtifactSource
from .true_foundry_artifact_source import TrueFoundryArtifactSource

ArtifactsDownloadArtifactsItem = typing.Union[TrueFoundryArtifactSource, HuggingfaceArtifactSource]
