# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.gateway_request_metadata_filter import GatewayRequestMetadataFilter
from ...types.span_attribute_filter import SpanAttributeFilter
from ...types.span_field_filter import SpanFieldFilter

QuerySpansRequestFiltersItem = typing.Union[SpanFieldFilter, SpanAttributeFilter, GatewayRequestMetadataFilter]
