# This file was auto-generated by Fern from our API Definition.

import typing

from .spark_executor_dynamic_scaling import SparkExecutorDynamicScaling
from .spark_executor_fixed_instances import SparkExecutorFixedInstances

SparkExecutorConfigInstances = typing.Union[SparkExecutorFixedInstances, SparkExecutorDynamicScaling]
