# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .artifact_manifest import ArtifactManifest
from .subject import Subject


class ArtifactVersion(UniversalBaseModel):
    id: str
    fqn: str
    created_by_subject: Subject
    created_at: typing.Optional[dt.datetime] = None
    updated_at: typing.Optional[dt.datetime] = None
    manifest: ArtifactManifest
    usage_code_snippet: typing.Optional[str] = None
    ml_repo_id: str
    tags: typing.Optional[typing.List[str]] = None
    artifact_id: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
