# This file was auto-generated by Fern from our API Definition.

import typing

from .per_thousand_embedding_tokens_cost_metric import PerThousandEmbeddingTokensCostMetric
from .per_thousand_tokens_cost_metric import PerThousandTokensCostMetric
from .public_cost_metric import PublicCostMetric

ModelCostMetric = typing.Union[PerThousandTokensCostMetric, PerThousandEmbeddingTokensCostMetric, PublicCostMetric]
