# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class BaseAutoscaling(UniversalBaseModel):
    min_replicas: int = pydantic.Field(default=1)
    """
    Minimum number of replicas to keep available
    """

    max_replicas: int = pydantic.Field()
    """
    Maximum number of replicas allowed for the component.
    """

    polling_interval: typing.Optional[int] = pydantic.Field(default=30)
    """
    This is the interval to check each trigger on.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
