# This file was auto-generated by Fern from our API Definition.

import typing

from .policy_mutation_operation import PolicyMutationOperation
from .policy_validation_operation import PolicyValidationOperation

PolicyManifestOperation = typing.Union[PolicyMutationOperation, PolicyValidationOperation]
