# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class VirtualAccountOwnedBy(UniversalBaseModel):
    """
    Names of the owners that own the virtual account
    """

    account: typing.Optional[str] = pydantic.Field(default=None)
    """
    The name of the account that owns this resource
    """

    team: str = pydantic.Field()
    """
    The name of the team that owns this resource
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
