# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class AwsSqsAssumedRoleBasedAuth(UniversalBaseModel):
    """
    AWS Assumed Role Based Auth
    """

    type: typing.Literal["assumed-role-based"] = pydantic.Field(default="assumed-role-based")
    """
    +value=assumed-role-based
    """

    assumed_role_arn: str = pydantic.Field()
    """
    ARN of the role you want to assume.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
