# This file was auto-generated by Fern from our API Definition.

import typing

from .gcp_gcr import GcpGcr
from .gcp_gcs import GcpGcs
from .gcp_gke_integration import GcpGkeIntegration
from .gcp_gsm import GcpGsm

GcpIntegrations = typing.Union[GcpGcr, GcpGcs, GcpGsm, GcpGkeIntegration]
