# This file was auto-generated by Fern from our API Definition.

import typing

from .spark_image import SparkImage
from .spark_image_build import SparkImageBuild

SparkJobImage = typing.Union[SparkImage, SparkImageBuild]
