# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .flyte_launch_plan_id import FlyteLaunchPlanId
from .flyte_launch_plan_spec import FlyteLaunchPlanSpec


class FlyteLaunchPlan(UniversalBaseModel):
    id: FlyteLaunchPlanId
    spec: FlyteLaunchPlanSpec
    closure: typing.Any

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
