# This file was auto-generated by Fern from our API Definition.

import typing

from .open_ai_moderations_guardrail_config_category_thresholds_value_harassment import (
    OpenAiModerationsGuardrailConfigCategoryThresholdsValueHarassment,
)

OpenAiModerationsGuardrailConfigCategoryThresholdsValue = typing.Union[
    float, OpenAiModerationsGuardrailConfigCategoryThresholdsValueHarassment
]
