# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class Kustomize(UniversalBaseModel):
    patch: typing.Optional[typing.Dict[str, typing.Any]] = pydantic.Field(default=None)
    """
    Content of kustomization.yaml to perform kustomize operation. Please do not include the `resources` section. It is filled in automatically
    """

    additions: typing.Optional[typing.List[typing.Dict[str, typing.Any]]] = pydantic.Field(default=None)
    """
    Additional kubernetes manifests to be included in the application
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
