# This file was auto-generated by Fern from our API Definition.

import typing

from .async_service import AsyncService
from .helm import Helm
from .job import Job
from .service import Service

ApplicationSetComponentsItem = typing.Union[Service, AsyncService, Job, Helm]
