# This file was auto-generated by Fern from our API Definition.

import typing

from .cloudera_token_auth import ClouderaTokenAuth
from .cloudera_workload_auth_token import ClouderaWorkloadAuthToken

ClouderaProviderAccountAuthData = typing.Union[ClouderaWorkloadAuthToken, ClouderaTokenAuth]
