# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class EnkryptAiKeyAuth(UniversalBaseModel):
    """
    Authentication method using Enkrypt AI API key
    """

    type: typing.Literal["api-key"] = pydantic.Field(default="api-key")
    """
    +value=api-key
    """

    api_key: str = pydantic.Field()
    """
    The API key for Enkrypt AI authentication
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
