# This file was auto-generated by Fern from our API Definition.

import typing

from .webhook_basic_auth import WebhookBasicAuth
from .webhook_bearer_auth import WebhookBearerAuth

WebhookIntegrationAuthData = typing.Union[WebhookBasicAuth, WebhookBearerAuth]
