# This file was auto-generated by Fern from our API Definition.

import typing

from .aws_bedrock_guardrail_config import AwsBedrockGuardrailConfig
from .azure_content_safety_guardrail_config import AzureContentSafetyGuardrailConfig
from .azure_pii_guardrail_config import AzurePiiGuardrailConfig
from .custom_guardrail_config import CustomGuardrailConfig
from .enkrypt_ai_guardrail_config import EnkryptAiGuardrailConfig
from .fiddler_guardrail_config import FiddlerGuardrailConfig
from .open_ai_moderations_guardrail_config import OpenAiModerationsGuardrailConfig
from .palo_alto_prisma_airs_guardrail_config import PaloAltoPrismaAirsGuardrailConfig
from .pangea_guardrail_config import PangeaGuardrailConfig
from .patronus_guardrail_config import PatronusGuardrailConfig
from .prompt_foo_guardrail_config import PromptFooGuardrailConfig

GuardrailConfigIntegrations = typing.Union[
    OpenAiModerationsGuardrailConfig,
    AwsBedrockGuardrailConfig,
    CustomGuardrailConfig,
    AzurePiiGuardrailConfig,
    AzureContentSafetyGuardrailConfig,
    EnkryptAiGuardrailConfig,
    PaloAltoPrismaAirsGuardrailConfig,
    PromptFooGuardrailConfig,
    FiddlerGuardrailConfig,
    PangeaGuardrailConfig,
    PatronusGuardrailConfig,
]
