# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.job_trigger_input import JobTriggerInput
from ...types.spark_job_trigger_input import SparkJobTriggerInput

TriggerJobRequestInput = typing.Union[JobTriggerInput, SparkJobTriggerInput]
