# This file was auto-generated by Fern from our API Definition.

import typing

from .databricks_api_key_auth import DatabricksApiKeyAuth
from .databricks_service_principal_auth import DatabricksServicePrincipalAuth

DatabricksProviderAccountAuthData = typing.Union[DatabricksServicePrincipalAuth, DatabricksApiKeyAuth]
