# This file was auto-generated by Fern from our API Definition.

import typing

from .cpu_utilization_metric import CpuUtilizationMetric
from .cron_metric import CronMetric
from .rps_metric import RpsMetric

ServiceAutoscalingMetrics = typing.Union[CpuUtilizationMetric, RpsMetric, CronMetric]
