# This file was auto-generated by Fern from our API Definition.

import typing

from ..core import enum

T_Result = typing.TypeVar("T_Result")


class AlertStatus(enum.StrEnum):
    FIRING = "firing"
    RESOLVED = "resolved"

    def visit(self, firing: typing.Callable[[], T_Result], resolved: typing.Callable[[], T_Result]) -> T_Result:
        if self is AlertStatus.FIRING:
            return firing()
        if self is AlertStatus.RESOLVED:
            return resolved()
