# This file was auto-generated by Fern from our API Definition.

import typing

from .aws_ecr import AwsEcr
from .aws_eks_integration import AwsEksIntegration
from .aws_parameter_store import AwsParameterStore
from .aws_s3 import AwsS3
from .aws_secrets_manager import AwsSecretsManager

AwsIntegrations = typing.Union[AwsEcr, AwsS3, AwsParameterStore, AwsSecretsManager, AwsEksIntegration]
