# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class SparkExecutorFixedInstances(UniversalBaseModel):
    """
    Fixed Instances
    """

    type: typing.Literal["fixed"] = pydantic.Field(default="fixed")
    """
    +value=fixed
    """

    count: int = pydantic.Field(default=1)
    """
    Number of instances to start
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
