# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class QuayBasicAuth(UniversalBaseModel):
    """
    Quay Basic Auth
    """

    type: typing.Literal["basic-auth"] = pydantic.Field(default="basic-auth")
    """
    +value=basic-auth
    """

    username: str = pydantic.Field()
    """
    The username for the basic authentication.
    """

    password: str = pydantic.Field()
    """
    The password for the basic authentication.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
