# This file was auto-generated by Fern from our API Definition.

import typing

from ..core import enum

T_Result = typing.TypeVar("T_Result")


class PangeaGuardType(enum.StrEnum):
    TEXT_GUARD = "textGuard"
    PII = "pii"

    def visit(self, text_guard: typing.Callable[[], T_Result], pii: typing.Callable[[], T_Result]) -> T_Result:
        if self is PangeaGuardType.TEXT_GUARD:
            return text_guard()
        if self is PangeaGuardType.PII:
            return pii()
