# This file was auto-generated by Fern from our API Definition.

import typing

from .mcp_server_integration import McpServerIntegration
from .virtual_mcp_server_integration import VirtualMcpServerIntegration

McpServerIntegrations = typing.Union[McpServerIntegration, VirtualMcpServerIntegration]
