# This file was auto-generated by Fern from our API Definition.

import typing

from .mcp_server_header_auth import McpServerHeaderAuth
from .mcp_server_o_auth2 import McpServerOAuth2
from .mcp_server_passthrough import McpServerPassthrough

McpServerAuth = typing.Union[McpServerHeaderAuth, McpServerOAuth2, McpServerPassthrough]
