# This file was auto-generated by Fern from our API Definition.

import typing

from .external_blob_storage_source import ExternalBlobStorageSource
from .local_artifact_source import LocalArtifactSource
from .true_foundry_managed_source import TrueFoundryManagedSource

ArtifactManifestSource = typing.Union[TrueFoundryManagedSource, ExternalBlobStorageSource, LocalArtifactSource]
