# This file was auto-generated by Fern from our API Definition.

import typing

from .aws_inferentia import AwsInferentia
from .gcp_tpu import GcpTpu
from .nvidia_gpu import NvidiaGpu
from .nvidia_miggpu import NvidiaMiggpu
from .nvidia_timeslicing_gpu import NvidiaTimeslicingGpu

ResourcesDevicesItem = typing.Union[NvidiaGpu, AwsInferentia, NvidiaMiggpu, NvidiaTimeslicingGpu, GcpTpu]
