# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from .base_workbench_input import BaseWorkbenchInput
from .workbench_image import WorkbenchImage


class RStudio(BaseWorkbenchInput):
    """
    Describes the configuration for the Rstudio server
    """

    type: typing.Literal["rstudio"] = pydantic.Field(default="rstudio")
    """
    +value=rstudio
    """

    image: WorkbenchImage

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
