# This file was auto-generated by Fern from our API Definition.

import typing

from .amqp_output_config import AmqpOutputConfig
from .core_nats_output_config import CoreNatsOutputConfig
from .kafka_output_config import KafkaOutputConfig
from .nats_output_config import NatsOutputConfig
from .sqs_output_config import SqsOutputConfig

WorkerConfigOutputConfig = typing.Union[
    SqsOutputConfig, NatsOutputConfig, CoreNatsOutputConfig, KafkaOutputConfig, AmqpOutputConfig
]
