# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .subject import Subject


class Account(UniversalBaseModel):
    id: typing.Optional[str] = None
    name: typing.Optional[str] = None
    tenant_name: typing_extensions.Annotated[str, FieldMetadata(alias="tenantName")]
    manifest: typing.Dict[str, typing.Any] = pydantic.Field()
    """
    Account manifest
    """

    created_by_subject: typing_extensions.Annotated[Subject, FieldMetadata(alias="createdBySubject")]
    created_at: typing_extensions.Annotated[typing.Optional[dt.datetime], FieldMetadata(alias="createdAt")] = None
    updated_at: typing_extensions.Annotated[typing.Optional[dt.datetime], FieldMetadata(alias="updatedAt")] = None
    is_editable: typing_extensions.Annotated[bool, FieldMetadata(alias="isEditable")]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
