# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .gateway_request_metadata_filter_operator import GatewayRequestMetadataFilterOperator
from .gateway_request_metadata_filter_value import GatewayRequestMetadataFilterValue


class GatewayRequestMetadataFilter(UniversalBaseModel):
    gateway_request_metadata_key: typing_extensions.Annotated[str, FieldMetadata(alias="gatewayRequestMetadataKey")]
    operator: GatewayRequestMetadataFilterOperator
    value: GatewayRequestMetadataFilterValue

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
