# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class Guardrails(UniversalBaseModel):
    """
    Guardrails
    """

    input_guardrails: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    List of guardrail names to apply to user input messages before processing.
    """

    output_guardrails: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    List of guardrail names to apply to AI response messages before returning to user.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
