# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .notification_target import NotificationTarget


class BudgetAlert(UniversalBaseModel):
    """
    Budget Alert
    """

    thresholds: typing.List[float] = pydantic.Field()
    """
    List of usage percentages (0-100) at which alerts should be triggered. Default thresholds are [75, 90, 95, 100].
    """

    notification_target: typing.List[NotificationTarget] = pydantic.Field()
    """
    Select where to send budget alert notifications
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
