# This file was auto-generated by Fern from our API Definition.

import typing

from .amqp_metric_config import AmqpMetricConfig
from .cron_metric import CronMetric
from .kafka_metric_config import KafkaMetricConfig
from .nats_metric_config import NatsMetricConfig
from .sqs_queue_metric_config import SqsQueueMetricConfig

AsyncServiceAutoscalingMetrics = typing.Union[
    SqsQueueMetricConfig, NatsMetricConfig, KafkaMetricConfig, CronMetric, AmqpMetricConfig
]
