# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class HeaderMatch(UniversalBaseModel):
    type: typing.Literal["header"] = pydantic.Field(default="header")
    """
    +value=header
    """

    name: str = pydantic.Field()
    """
    Header name to match on
    """

    exact_match: str = pydantic.Field(default="")
    """
    Header value to match on
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
