# This file was auto-generated by Fern from our API Definition.

import typing

from .assistant_message import AssistantMessage
from .developer_message import DeveloperMessage
from .system_message import SystemMessage
from .tool_message import ToolMessage
from .user_message import UserMessage

ChatPromptManifestMessagesItem = typing.Union[
    SystemMessage, AssistantMessage, UserMessage, ToolMessage, DeveloperMessage
]
