# This file was auto-generated by Fern from our API Definition.

import typing

from ..core import enum

T_Result = typing.TypeVar("T_Result")


class PromptFooGuardType(enum.StrEnum):
    GUARD_CHECK = "guard_check"
    PII_REDACTION = "pii_redaction"
    HARMFUL_DETECTION = "harmful_detection"

    def visit(
        self,
        guard_check: typing.Callable[[], T_Result],
        pii_redaction: typing.Callable[[], T_Result],
        harmful_detection: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is PromptFooGuardType.GUARD_CHECK:
            return guard_check()
        if self is PromptFooGuardType.PII_REDACTION:
            return pii_redaction()
        if self is PromptFooGuardType.HARMFUL_DETECTION:
            return harmful_detection()
