# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .cluster_gateway import ClusterGateway


class GetSuggestedDeploymentEndpointResponse(UniversalBaseModel):
    host: str = pydantic.Field()
    """
    Host name
    """

    path: typing.Optional[str] = pydantic.Field(default=None)
    """
    Path
    """

    gateway: typing.Optional[ClusterGateway] = pydantic.Field(default=None)
    """
    Gateway configuration
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
