# This file was auto-generated by Fern from our API Definition.

import typing

from .patronus_answer_relevance_evaluator import PatronusAnswerRelevanceEvaluator
from .patronus_glider_evaluator import PatronusGliderEvaluator
from .patronus_judge_evaluator import PatronusJudgeEvaluator
from .patronus_phi_evaluator import PatronusPhiEvaluator
from .patronus_pii_evaluator import PatronusPiiEvaluator
from .patronus_toxicity_evaluator import PatronusToxicityEvaluator

PatronusEvaluator = typing.Union[
    PatronusAnswerRelevanceEvaluator,
    PatronusGliderEvaluator,
    PatronusJudgeEvaluator,
    PatronusPiiEvaluator,
    PatronusPhiEvaluator,
    PatronusToxicityEvaluator,
]
