# This file was auto-generated by Fern from our API Definition.

import typing

from .internal_artifact_version import InternalArtifactVersion
from .internal_model_version import InternalModelVersion

InternalListArtifactVersionsResponseDataItem = typing.Union[InternalArtifactVersion, InternalModelVersion]
