# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from .load_balancing_when import LoadBalancingWhen
from .weight_based_load_balancing import WeightBasedLoadBalancing


class WeightBasedLoadBalancingRule(WeightBasedLoadBalancing):
    """
    Weight-based Load Balancing Rule
    """

    id: str = pydantic.Field()
    """
    Unique identifier for the rule
    """

    when: LoadBalancingWhen

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
