# This file was auto-generated by Fern from our API Definition.

import typing

from .git_source import GitSource
from .local_source import LocalSource
from .remote_source import RemoteSource

BuildBuildSource = typing.Union[RemoteSource, GitSource, LocalSource]
