# This file was auto-generated by Fern from our API Definition.

import typing

from .email import Email
from .pager_duty import PagerDuty
from .slack_bot import SlackBot

NotificationTargetForAlertRule = typing.Union[Email, SlackBot, PagerDuty]
