# This file was auto-generated by Fern from our API Definition.

import typing

from .dynamic_volume_config import DynamicVolumeConfig
from .static_volume_config import StaticVolumeConfig

VolumeConfig = typing.Union[DynamicVolumeConfig, StaticVolumeConfig]
