# This file was auto-generated by Fern from our API Definition.

import typing

from ..core import enum

T_Result = typing.TypeVar("T_Result")


class ParamParamType(enum.StrEnum):
    STRING = "string"
    ML_REPO = "ml_repo"

    def visit(self, string: typing.Callable[[], T_Result], ml_repo: typing.Callable[[], T_Result]) -> T_Result:
        if self is ParamParamType.STRING:
            return string()
        if self is ParamParamType.ML_REPO:
            return ml_repo()
