# This file was auto-generated by Fern from our API Definition.

import typing

from .latency_based_load_balancing_rule import LatencyBasedLoadBalancingRule
from .priority_based_load_balancing_rule import PriorityBasedLoadBalancingRule
from .weight_based_load_balancing_rule import WeightBasedLoadBalancingRule

LoadBalancingRule = typing.Union[
    WeightBasedLoadBalancingRule, LatencyBasedLoadBalancingRule, PriorityBasedLoadBalancingRule
]
