# This file was auto-generated by Fern from our API Definition.

import typing

from .async_service_autoscaling import AsyncServiceAutoscaling

AsyncServiceReplicas = typing.Union[float, AsyncServiceAutoscaling]
