# This file was auto-generated by Fern from our API Definition.

import typing

from .git_source import GitSource
from .remote_source import RemoteSource

SparkImageBuildBuildSource = typing.Union[GitSource, RemoteSource]
