# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .rate_limit_unit import RateLimitUnit
from .rate_limit_when import RateLimitWhen


class RateLimitRule(UniversalBaseModel):
    """
    Rate Limit Rule
    """

    id: str = pydantic.Field()
    """
    Unique identifier for the rule
    """

    when: RateLimitWhen
    limit_to: int = pydantic.Field()
    """
    Maximum number of requests or tokens allowed
    """

    unit: RateLimitUnit

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
