# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .infer_method_name import InferMethodName


class SklearnModelSchema(UniversalBaseModel):
    infer_method_name: InferMethodName = pydantic.Field()
    """
    Name of the method used for inference
    """

    inputs: typing.List[typing.Dict[str, typing.Any]] = pydantic.Field()
    """
    Schema of the input
    """

    outputs: typing.List[typing.Dict[str, typing.Any]] = pydantic.Field()
    """
    Schema of the output
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
