# This file was auto-generated by Fern from our API Definition.

import typing

from .pip import Pip
from .poetry import Poetry
from .uv import Uv

PythonBuildPythonDependencies = typing.Union[Pip, Uv, Poetry]
