# This file was auto-generated by Fern from our API Definition.

import typing

from .secret_mount import SecretMount
from .string_data_mount import StringDataMount
from .volume_mount import VolumeMount

ContainerTaskConfigMountsItem = typing.Union[SecretMount, StringDataMount, VolumeMount]
