# This file was auto-generated by Fern from our API Definition.

import typing

from .container_task_config import ContainerTaskConfig
from .py_spark_task_config import PySparkTaskConfig
from .python_task_config import PythonTaskConfig

FlyteTaskCustomTruefoundry = typing.Union[PythonTaskConfig, ContainerTaskConfig, PySparkTaskConfig]
