# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class TrueFoundryInteractiveLogin(UniversalBaseModel):
    """
    Login with truefoundry
    """

    type: typing.Literal["truefoundry_oauth"] = pydantic.Field(default="truefoundry_oauth")
    """
    +value=truefoundry_oauth
    """

    bypass_auth_paths: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    List of paths that will bypass auth.
    needs to start with a forward slash(/) and should not contain wildcards(*)
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
