# This file was auto-generated by Fern from our API Definition.

import typing

from .artifact_manifest import ArtifactManifest
from .chat_prompt_manifest import ChatPromptManifest
from .model_manifest import ModelManifest

BaseArtifactVersionManifest = typing.Union[ModelManifest, ChatPromptManifest, ArtifactManifest]
