# This file was auto-generated by Fern from our API Definition.

import typing

from .docker_file_build import DockerFileBuild
from .python_build import PythonBuild

BuildBuildSpec = typing.Union[DockerFileBuild, PythonBuild]
