# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class TrueFoundryArtifactSource(UniversalBaseModel):
    """
    Input for Artifact from TrueFoundry Artifact Registry
    """

    type: typing.Literal["truefoundry-artifact"] = pydantic.Field(default="truefoundry-artifact")
    """
    +value=truefoundry-artifact
    """

    artifact_version_fqn: str = pydantic.Field()
    """
    Artifact or Model Version FQN of the artifact to be downloaded
    """

    download_path_env_variable: str = pydantic.Field()
    """
    Environment variable which will contain the download path of the artifact
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
