# This file was auto-generated by Fern from our API Definition.

import typing

from .mcp_server_with_fqn import McpServerWithFqn
from .mcp_server_with_url import McpServerWithUrl

ChatPromptManifestMcpServersItem = typing.Union[McpServerWithFqn, McpServerWithUrl]
