# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .load_balance_target import LoadBalanceTarget


class WeightBasedLoadBalancing(UniversalBaseModel):
    """
    Weight-based Load Balancing
    """

    type: typing.Literal["weight-based-routing"] = pydantic.Field(default="weight-based-routing")
    """
    Routing Type
    """

    load_balance_targets: typing.List[LoadBalanceTarget] = pydantic.Field()
    """
    List of targets for load balancing with weights
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
