# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class SparkJobJavaEntrypoint(UniversalBaseModel):
    """
    java
    """

    type: typing.Literal["java"] = pydantic.Field(default="java")
    """
    +value=java
    """

    main_application_file: str = pydantic.Field()
    """
    The main application file to be executed by the spark job.
    """

    main_class: str = pydantic.Field()
    """
    The main class to be executed by the spark job.
    """

    arguments: typing.Optional[str] = pydantic.Field(default=None)
    """
    Arguments to be passed to the main application file.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
