# This file was auto-generated by Fern from our API Definition.

import typing

from ....types.artifact_manifest import ArtifactManifest
from ....types.chat_prompt_manifest import ChatPromptManifest
from ....types.data_directory_manifest import DataDirectoryManifest
from ....types.model_manifest import ModelManifest
from ....types.tracing_project_manifest import TracingProjectManifest

ApplyMlEntityRequestManifest = typing.Union[
    ModelManifest, ChatPromptManifest, ArtifactManifest, DataDirectoryManifest, TracingProjectManifest
]
